@@ -66,6 +66,7 @@ G_BEGIN_DECLS
 #define EMPATHY_PREFS_CHAT_AVATAR_IN_ICON          "avatar-in-icon"
 #define EMPATHY_PREFS_CHAT_WEBKIT_DEVELOPER_TOOLS  "enable-webkit-developer-tools"
 #define EMPATHY_PREFS_CHAT_ROOM_LAST_ACCOUNT       "room-last-account"
+#define EMPATHY_PREFS_CHAT_SEND_CHAT_STATES        "send-chat-states"
 
 #define EMPATHY_PREFS_UI_SCHEMA EMPATHY_PREFS_SCHEMA ".ui"
 #define EMPATHY_PREFS_UI_SEPARATE_CHAT_WINDOWS     "separate-chat-windows"
@@ -77,6 +78,7 @@ G_BEGIN_DECLS
 #define EMPATHY_PREFS_UI_COMPACT_CONTACT_LIST      "compact-contact-list"
 #define EMPATHY_PREFS_UI_CHAT_WINDOW_PANED_POS     "chat-window-paned-pos"
 #define EMPATHY_PREFS_UI_SHOW_OFFLINE              "show-offline"
+#define EMPATHY_PREFS_UI_SHOW_GROUPS               "show-groups"
 
 #define EMPATHY_PREFS_CONTACTS_SCHEMA EMPATHY_PREFS_SCHEMA ".contacts"
 #define EMPATHY_PREFS_CONTACTS_SORT_CRITERIUM      "sort-criterium"
