@@ -29,13 +29,10 @@
 #include <telepathy-glib/interfaces.h>
 #include <telepathy-glib/simple-approver.h>
 
-#include <telepathy-yell/telepathy-yell.h>
-
 #include <libempathy/empathy-presence-manager.h>
 #include <libempathy/empathy-tp-contact-factory.h>
 #include <libempathy/empathy-connection-aggregator.h>
 #include <libempathy/empathy-tp-chat.h>
-#include <libempathy/empathy-tp-streamed-media.h>
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-gsettings.h>
 
@@ -45,6 +42,7 @@
 #include <libempathy-gtk/empathy-contact-dialogs.h>
 #include <libempathy-gtk/empathy-sound-manager.h>
 #include <libempathy-gtk/empathy-ui-utils.h>
+#include <libempathy-gtk/empathy-call-utils.h>
 
 #include "empathy-event-manager.h"
 #include "empathy-roster-window.h"
@@ -409,14 +407,10 @@ reject_channel_claim_cb (GObject *source,
       goto out;
     }
 
-  if (EMPATHY_IS_TP_STREAMED_MEDIA (user_data))
+  if (TP_IS_CALL_CHANNEL (user_data))
     {
-      empathy_tp_streamed_media_close (user_data);
-    }
-  else if (TPY_IS_CALL_CHANNEL (user_data))
-    {
-      tpy_call_channel_hangup_async (user_data,
-          TPY_CALL_STATE_CHANGE_REASON_USER_REQUESTED,
+      tp_call_channel_hangup_async (user_data,
+          TP_CALL_STATE_CHANGE_REASON_USER_REQUESTED,
           "", "", NULL, NULL);
       tp_channel_close_async (user_data, NULL, NULL);
     }
@@ -474,7 +468,7 @@ event_manager_call_window_confirmation_dialog_response_cb (GtkDialog *dialog,
     }
   else if (response == ACCEPT_WITHOUT_VIDEO)
     {
-      tpy_call_channel_send_video (TPY_CALL_CHANNEL (approval->main_channel),
+      empathy_call_channel_send_video (TP_CALL_CHANNEL (approval->main_channel),
         FALSE);
       event_manager_approval_approve (approval);
     }
@@ -500,17 +494,11 @@ event_channel_process_voip_func (EventPriv *event)
       return;
     }
 
-  if (etype == EMPATHY_EVENT_TYPE_VOIP)
+  if (etype == EMPATHY_EVENT_TYPE_CALL)
     {
-      EmpathyTpStreamedMedia *call;
-      call = EMPATHY_TP_STREAMED_MEDIA (event->approval->handler_instance);
-      video = empathy_tp_streamed_media_has_initial_video (call);
-    }
-  else if (etype == EMPATHY_EVENT_TYPE_CALL)
-    {
-      TpyCallChannel *call;
-      call = TPY_CALL_CHANNEL (event->approval->handler_instance);
-      g_object_get (G_OBJECT (call), "initial-video", &video, NULL);
+      TpCallChannel *call;
+      call = TP_CALL_CHANNEL (event->approval->handler_instance);
+      video = tp_call_channel_has_initial_video (call, NULL);
     }
   else
     {
@@ -638,7 +626,7 @@ event_manager_approval_done (EventManagerApproval *approval)
       channel_type = tp_channel_get_channel_type_id (approval->main_channel);
 
       if (channel_type == TP_IFACE_QUARK_CHANNEL_TYPE_STREAMED_MEDIA ||
-          channel_type == TPY_IFACE_QUARK_CHANNEL_TYPE_CALL)
+          channel_type == TP_IFACE_QUARK_CHANNEL_TYPE_CALL)
         {
           priv->ringing--;
           if (priv->ringing == 0)
@@ -676,14 +664,14 @@ cdo_invalidated_cb (TpProxy *cdo,
 }
 
 static void
-event_manager_call_state_changed_cb (TpyCallChannel *call,
-  TpyCallState state,
-  TpyCallFlags flags,
-   const GValueArray *call_state_reason,
-  GHashTable *call_state_details,
+event_manager_call_state_changed_cb (TpCallChannel *call,
+  TpCallState state,
+  TpCallFlags flags,
+  TpCallStateReason *reason,
+  GHashTable *details,
   EventManagerApproval *approval)
 {
-  if (state == TPY_CALL_STATE_ENDED)
+  if (state == TP_CALL_STATE_ENDED)
     {
       DEBUG ("Call ended, seems we missed it :/");
       reject_approval (approval);
@@ -700,11 +688,11 @@ event_manager_call_channel_got_contact_cb (TpConnection *connection,
   EventManagerApproval *approval = (EventManagerApproval *) user_data;
   EmpathyEventManagerPriv *priv = GET_PRIV (approval->manager);
   GtkWidget *window;
-  TpyCallChannel *call;
+  TpCallChannel *call;
   gchar *header;
   gboolean video;
 
-  call = TPY_CALL_CHANNEL (approval->handler_instance);
+  call = TP_CALL_CHANNEL (approval->handler_instance);
 
   if (error != NULL)
     {
@@ -713,7 +701,7 @@ event_manager_call_channel_got_contact_cb (TpConnection *connection,
       return;
     }
 
-  if (tpy_call_channel_get_state (call, NULL, NULL) == TPY_CALL_STATE_ENDED)
+  if (tp_call_channel_get_state (call, NULL, NULL, NULL) == TP_CALL_STATE_ENDED)
     {
       DEBUG ("Call already ended, seems we missed it :/");
       reject_approval (approval);
@@ -748,54 +736,6 @@ event_manager_call_channel_got_contact_cb (TpConnection *connection,
   g_object_unref (window);
 }
 
-static void
-event_manager_media_channel_got_contact (EventManagerApproval *approval)
-{
-  EmpathyEventManagerPriv *priv = GET_PRIV (approval->manager);
-  GtkWidget *window = empathy_roster_window_dup ();
-  gchar *header;
-  EmpathyTpStreamedMedia *call;
-  gboolean video;
-
-  call = EMPATHY_TP_STREAMED_MEDIA (approval->handler_instance);
-
-  video = empathy_tp_streamed_media_has_initial_video (call);
-
-  header = g_strdup_printf (
-    video ? _("Incoming video call from %s") :_("Incoming call from %s"),
-    empathy_contact_get_alias (approval->contact));
-
-  event_manager_add (approval->manager, NULL,
-      approval->contact, EMPATHY_EVENT_TYPE_VOIP,
-      video ? EMPATHY_IMAGE_VIDEO_CALL : EMPATHY_IMAGE_VOIP,
-      header, NULL, approval,
-      event_channel_process_voip_func, NULL);
-
-  g_free (header);
-
-  priv->ringing++;
-  if (priv->ringing == 1)
-    empathy_sound_manager_start_playing (priv->sound_mgr, window,
-        EMPATHY_SOUND_PHONE_INCOMING, MS_BETWEEN_RING);
-
-  g_object_unref (window);
-}
-
-static void
-event_manager_media_channel_contact_changed_cb (EmpathyTpStreamedMedia *call,
-  GParamSpec *param, EventManagerApproval *approval)
-{
-  EmpathyContact *contact;
-
-  g_object_get (G_OBJECT (call), "contact", &contact, NULL);
-
-  if (contact == NULL)
-    return;
-
-  approval->contact = contact;
-  event_manager_media_channel_got_contact (approval);
-}
-
 static void
 invite_dialog_response_cb (GtkDialog *dialog,
                            gint response,
@@ -982,7 +922,7 @@ find_main_channel (GList *channels)
       channel_type = tp_channel_get_channel_type_id (channel);
 
       if (channel_type == TP_IFACE_QUARK_CHANNEL_TYPE_STREAMED_MEDIA ||
-          channel_type == TPY_IFACE_QUARK_CHANNEL_TYPE_CALL ||
+          channel_type == TP_IFACE_QUARK_CHANNEL_TYPE_CALL ||
           channel_type == TP_IFACE_QUARK_CHANNEL_TYPE_FILE_TRANSFER ||
           channel_type == TP_IFACE_QUARK_CHANNEL_TYPE_SERVER_AUTHENTICATION)
         return channel;
@@ -1081,32 +1021,9 @@ approve_channels (TpSimpleApprover *approver,
           event_manager_chat_message_received_cb (tp_chat, msg, approval);
         }
     }
-  else if (channel_type == TP_IFACE_QUARK_CHANNEL_TYPE_STREAMED_MEDIA)
+  else if (channel_type == TP_IFACE_QUARK_CHANNEL_TYPE_CALL)
     {
-      EmpathyContact *contact;
-      EmpathyTpStreamedMedia *call = empathy_tp_streamed_media_new (account,
-        channel);
-
-      approval->handler_instance = G_OBJECT (call);
-
-      g_object_get (G_OBJECT (call), "contact", &contact, NULL);
-
-      if (contact == NULL)
-        {
-          g_signal_connect (call, "notify::contact",
-            G_CALLBACK (event_manager_media_channel_contact_changed_cb),
-            approval);
-        }
-      else
-        {
-          approval->contact = contact;
-          event_manager_media_channel_got_contact (approval);
-        }
-
-    }
-  else if (channel_type == TPY_IFACE_QUARK_CHANNEL_TYPE_CALL)
-    {
-      TpyCallChannel *call = TPY_CALL_CHANNEL (channel);
+      TpCallChannel *call = TP_CALL_CHANNEL (channel);
       const gchar *id;
 
       approval->handler_instance = g_object_ref (call);
@@ -1510,7 +1427,7 @@ empathy_event_manager_init (EmpathyEventManager *manager)
   tp_base_client_take_approver_filter (priv->approver,
       tp_asv_new (
         TP_PROP_CHANNEL_CHANNEL_TYPE, G_TYPE_STRING,
-          TPY_IFACE_CHANNEL_TYPE_CALL,
+          TP_IFACE_CHANNEL_TYPE_CALL,
         TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, G_TYPE_UINT, TP_HANDLE_TYPE_CONTACT,
         NULL));
 
