@@ -25,11 +25,8 @@
 #include <libnotify/notify.h>
 #include <telepathy-glib/telepathy-glib.h>
 
-#include <telepathy-yell/telepathy-yell.h>
-
-#include <libempathy/empathy-tp-streamed-media.h>
-
 #include <libempathy-gtk/empathy-notify-manager.h>
+#include <libempathy-gtk/empathy-call-utils.h>
 
 #include "empathy-event-manager.h"
 
@@ -127,8 +124,8 @@ notification_approve_no_video_cb (NotifyNotification *notification,
 {
   if (self->priv->event)
     {
-      tpy_call_channel_send_video (
-          TPY_CALL_CHANNEL (self->priv->event->handler_instance),
+      empathy_call_channel_send_video (
+          TP_CALL_CHANNEL (self->priv->event->handler_instance),
           FALSE);
       empathy_event_approve (self->priv->event);
     }
@@ -191,14 +188,9 @@ add_notification_actions (EmpathyNotificationsApprover *self,
           self, NULL);
       break;
 
-    case EMPATHY_EVENT_TYPE_VOIP:
     case EMPATHY_EVENT_TYPE_CALL:
-      if (self->priv->event->type == EMPATHY_EVENT_TYPE_VOIP)
-        video = empathy_tp_streamed_media_has_initial_video (
-            EMPATHY_TP_STREAMED_MEDIA (self->priv->event->handler_instance));
-      else
-        video = tpy_call_channel_has_initial_video (
-            TPY_CALL_CHANNEL (self->priv->event->handler_instance));
+        video = tp_call_channel_has_initial_video (
+            TP_CALL_CHANNEL (self->priv->event->handler_instance), NULL);
 
       notify_notification_add_action (notification,
         "reject", _("Reject"), (NotifyActionCallback) notification_decline_cb,
@@ -261,7 +253,6 @@ notification_is_urgent (EmpathyNotificationsApprover *self,
    * interact ASAP */
   switch (self->priv->event->type) {
     case EMPATHY_EVENT_TYPE_CHAT:
-    case EMPATHY_EVENT_TYPE_VOIP:
     case EMPATHY_EVENT_TYPE_CALL:
     case EMPATHY_EVENT_TYPE_TRANSFER:
     case EMPATHY_EVENT_TYPE_INVITATION:
@@ -289,7 +280,6 @@ get_category_for_event_type (EmpathyEventType type)
       return "presence.online";
     case EMPATHY_EVENT_TYPE_PRESENCE_OFFLINE:
       return "presence.offline";
-    case EMPATHY_EVENT_TYPE_VOIP:
     case EMPATHY_EVENT_TYPE_CALL:
       return "x-empathy.call.incoming";
     case EMPATHY_EVENT_TYPE_TRANSFER:
